as.data.frame.Rgof_power_adaptive: Convert adaptive Rgof power output to a data frame

View source: R/gof_power_adaptive.R

as.data.frame.Rgof_power_adaptiveR Documentation

Convert adaptive Rgof power output to a data frame

Description

Convert adaptive Rgof power output to a data frame

Usage

## S3 method for class 'Rgof_power_adaptive'
as.data.frame(x, ...)

Arguments

x

Object returned by gof_power_adaptive().

...

Unused.


Rgof documentation built on Sept. 13, 2026, 5:06 p.m.