as.data.frame.Rgof_test: Convert an Rgof test result to a data frame

View source: R/gof_test.R

as.data.frame.Rgof_testR Documentation

Convert an Rgof test result to a data frame

Description

Convert an Rgof test result to a data frame

Usage

## S3 method for class 'Rgof_test'
as.data.frame(x, row.names = NULL, optional = FALSE, ...)

Arguments

x

An object of class "Rgof_test".

row.names

Ignored.

optional

Ignored.

...

Currently unused.

Value

A data frame with columns method, statistic, and p.value.


Rgof documentation built on Sept. 13, 2026, 5:06 p.m.