test_methods: This function checks whether the correct methods have been...

View source: R/test_methods.R

test_methodsR Documentation

This function checks whether the correct methods have been requested

Description

This function checks whether the correct methods have been requested

Usage

test_methods(doMethods, Continuous, WithWeights)

Arguments

doMethods

="all" Which methods should be included?

Continuous

is data continuous

WithWeights

with weights?

Value

TRUE or FALSE


Rgof documentation built on Oct. 6, 2026, 1:06 a.m.